# redhat.sap_install Ansible Collection

![Ansible Lint](https://github.com/sap-linuxlab/community.sap_install/actions/workflows/ansible-lint.yml/badge.svg?branch=main)

This Ansible Collection executes various SAP Software installations and configuration tasks for running various SAP solutions and deployment scenarios on Linux operating systems (RHEL or SLES).

This includes handlers for SAP HANA database lifecycle manager (HDBLCM) and SAP Software Provisioning Manager (SWPM), and can be combined with other Ansible Collections to provide end-to-end automation _(e.g. provision, download, install, operations)_.


**Please read the [full documentation](/docs#readme) for how-to guidance, requirements, and all other details. Summary documentation is below:**

## Functionality

This Ansible Collection contains roles for:
  - **Preparing RHEL 7.9, RHEL 8, and RHEL 9 systems for the installation of SAP HANA and NetWeaver software**

    *NOTE*: The preconfigure roles in this version of the collection redhat.sap_install also contain code for configuring non-RHEL managed nodes. Only the configuration of RHEL managed nodes is supported by Red Hat.

  - **Installing SAP HANA standalone and scale-out, in a non clustered and clustered environment**

  - **Installing SAP software via the SAP Software Provisioning Manager (SWPM)**

    *NOTE*: This version of the collection redhat.sap_install contains the role `sap_swpm` with a support scope of *Technology Preview*
    for the following deployment scenarios:
    S/4HANA 2021 and S/4HANA 2022 single-host installation on RHEL 8.4, 8.6, 8.8, 9.0, 9.2 x86_64 and ppc64le. Only the `default` mode of the role `sap_swpm` is supported. All other functionality of this role is currently not supported by Red Hat.

  - **Configuring a hypervisor running VMs for SAP HANA**

  - **Configuring settings for a guest (VM) running on RHV/KVM for SAP HANA**

## Contents

Within this Ansible Collection, there are various Ansible Roles and no custom Ansible Modules.

### Ansible Roles

| Name | Summary | Support Status |
| :--- | :--- | :--- |
| [sap_general_preconfigure](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_general_preconfigure) | configure general OS settings for SAP software | Fully supported for RHEL managed nodes |
| [sap_ha_install_hana_hsr](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_ha_install_hana_hsr) | install SAP HANA System Replication | Technology Preview |
| [sap_ha_pacemaker_cluster](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_ha_pacemaker_cluster) | install and configure pacemaker and SAP resources | Technology Preview |
| [sap_hana_install](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_hana_install) | install SAP HANA via HDBLCM | Fully supported |
| [sap_hana_preconfigure](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_hana_preconfigure) | configure settings for SAP HANA database server | Fully supported for RHEL managed nodes |
| [sap_hypervisor_node_preconfigure](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_hypervisor_node_preconfigure) | configure a hypervisor running VMs for SAP HANA | Technology Preview |
| [sap_netweaver_preconfigure](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_netweaver_preconfigure) | configure settings for SAP NetWeaver application server | Fully supported for RHEL managed nodes |
| [sap_swpm](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_swpm) | install SAP Software via SWPM | Technology Preview for certain deployment scenarios only |
| [sap_vm_preconfigure](https://github.com/sap-linuxlab/community.sap_install/tree/main/roles/sap_vm_preconfigure) | configure settings for a guest (VM) running on RHV/KVM for SAP HANA | Technology Preview |

**_Notes_**:

In general the "preconfigure" roles are prerequisites for the corresponding installation roles.
The logic has been separated to support a flexible execution of the different steps.

## License

- [Apache 2.0](./LICENSE)

## Contributors

Contributors to the Ansible Roles within this Ansible Collection are shown in the README.md file of each role.
